<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Google_Client;
use Google_Service_Analytics;
use Google_Service_AnalyticsReporting;
use Google_Service_AnalyticsReporting_DateRange;
use Google_Service_AnalyticsReporting_Dimension;
use Google_Service_AnalyticsReporting_GetReportsRequest;
use Google_Service_AnalyticsReporting_Metric;
use Google_Service_AnalyticsReporting_ReportRequest;
use Illuminate\Http\Request;

use Spatie\Analytics\Analytics;
use Spatie\Analytics\Period;

class AnalysisController extends Controller
{
    protected $visitors;

    public function index()
    {
        $analytics = $this->initializeAnalytics();
        $response = $this->getReport($analytics);
        $this->printResults($response);


    }

    public function initializeAnalytics()
    {
        $KEY_FILE_LOCATION = storage_path('app/analytics/service-account-credentials.json');
        $client = new Google_Client();
        $client->setApplicationName("Hello Analytics Reporting");
        $client->setAuthConfig($KEY_FILE_LOCATION);
        $client->setScopes(['https://www.googleapis.com/auth/analytics.readonly']);
        $analytics = new Google_Service_AnalyticsReporting($client);

        return $analytics;
    }

    public function getReport($analytics) {

        // Replace with your view ID, for example XXXX.
        $VIEW_ID = "237273566";

        // Create the DateRange object.
        $dateRange = new Google_Service_AnalyticsReporting_DateRange();
        $dateRange->setStartDate("7daysAgo");
        $dateRange->setEndDate("today");

        // Create the Metrics object.
        $sessions = new Google_Service_AnalyticsReporting_Metric();
        $sessions->setExpression("ga:sessions");
        $sessions->setAlias("sessions");

        $users = new Google_Service_AnalyticsReporting_Metric();
        $users->setExpression("ga:users");
        $users->setAlias("users");

        $organicSearches = new Google_Service_AnalyticsReporting_Metric();
        $organicSearches->setExpression("ga:organicSearches");
        $organicSearches->setAlias("organicSearches");

        $avgDomainLookupTime = new Google_Service_AnalyticsReporting_Metric();
        $avgDomainLookupTime->setExpression("ga:avgDomainLookupTime");
        $avgDomainLookupTime->setAlias("avgDomainLookupTime");


        $avgPageLoadTime = new Google_Service_AnalyticsReporting_Metric();
        $avgPageLoadTime->setExpression("ga:avgPageLoadTime");
        $avgPageLoadTime->setAlias("avgPageLoadTime");

        $bounceRate = new Google_Service_AnalyticsReporting_Metric();
        $bounceRate->setExpression("ga:bounceRate");
        $bounceRate->setAlias("ga:bounceRate");

        $sessionDuration = new Google_Service_AnalyticsReporting_Metric();
        $sessionDuration->setExpression("ga:sessionDuration");
        $sessionDuration->setAlias("ga:sessionDuration");

        $pageviews = new Google_Service_AnalyticsReporting_Metric();
        $pageviews->setExpression("ga:pageviews");
        $pageviews->setAlias("ga:pageviews");

        $avgSessionDuration = new Google_Service_AnalyticsReporting_Metric();
        $avgSessionDuration->setExpression("ga:avgSessionDuration");
        $avgSessionDuration->setAlias("ga:avgSessionDuration");

        $country = new Google_Service_AnalyticsReporting_Dimension();
        $country->setName("ga:country");

        $sessionDurationBucket = new Google_Service_AnalyticsReporting_Dimension();
        $sessionDurationBucket->setName("ga:sessionDurationBucket");

        $pagePath = new Google_Service_AnalyticsReporting_Dimension();
        $pagePath->setName("ga:pagePath");

        $date = new Google_Service_AnalyticsReporting_Dimension();
        $date->setName("ga:date");

        $minute = new Google_Service_AnalyticsReporting_Dimension();
        $minute->setName("ga:minute");

        $hour = new Google_Service_AnalyticsReporting_Dimension();
        $hour->setName("ga:hour");

        $pageTitle = new Google_Service_AnalyticsReporting_Dimension();
        $pageTitle->setName("ga:pageTitle");
        // Create the ReportRequest object.
        $request = new Google_Service_AnalyticsReporting_ReportRequest();
        $request->setViewId($VIEW_ID);
        $request->setDateRanges($dateRange);
        $request->setMetrics(array($sessions,$users,$avgDomainLookupTime,$avgPageLoadTime,$bounceRate,$sessionDuration ,$avgSessionDuration, $pageviews));
        $request->setDimensions(array($country , $pagePath ,$date ,$minute , $hour , $pageTitle));

        $body = new Google_Service_AnalyticsReporting_GetReportsRequest();
        $body->setReportRequests( array( $request) );
        return $analytics->reports->batchGet( $body );
    }


    public function printResults($reports) {
        for ( $reportIndex = 0; $reportIndex < count( $reports ); $reportIndex++ ) {
            $report = $reports[ $reportIndex ];
            $header = $report->getColumnHeader();
            $dimensionHeaders = $header->getDimensions();
            $metricHeaders = $header->getMetricHeader()->getMetricHeaderEntries();
            $rows = $report->getData()->getRows();

            for ( $rowIndex = 0; $rowIndex < count($rows); $rowIndex++) {
                $row = $rows[ $rowIndex ];
               $dimensions = $row->getDimensions();
                $metrics = $row->getMetrics();
dd($metrics);
               if(!empty($dimensionHeaders))
               {
                   for ($i = 0; $i < count($dimensionHeaders) && $i < count($dimensions); $i++) {
                       print($dimensionHeaders[$i] . ": " . $dimensions[$i]);
                   }
               }

               /* for ($j = 0; $j < count($metrics); $j++) {
                    $values = $metrics[$j]->getValues();
                    for ($k = 0; $k < count($values); $k++) {
                        $entry = $metricHeaders[$k];
                        print($entry->getName() . ": " . $values[$k]);
                    }
                }*/
            }
        }
    }

}
