<?php

namespace App\Http\Controllers\Admin;

use App\Advertisement;
use App\Categories;
use App\Domains;
use App\FinanceDomain;
use App\GeoLocation;
use App\Http\Controllers\Controller;
use App\Imports\DomainsImport;
use App\Orders;
use App\Payments;
use App\Plans;
use App\Seo;
use App\SEOWEB;
use App\Subscription;
use App\UserSubscribedDomain;
use Carbon\Carbon;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Str;
use Response;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Redirect;
use Maatwebsite\Excel\Facades\Excel;
use Yajra\DataTables\Facades\DataTables;
use function GuzzleHttp\Promise\all;
use File;
class PortfolioController extends Controller
{
    public function index(Request $request)
    {
        $domains = Domains::where('sold','0')->get();
        if ($request->ajax()) {
            return Datatables::of($domains)->addIndexColumn()
                ->addColumn('created_at', function ($row) {
                    return Carbon::parse($row->created_at)->format('m/d/y h:i:s');
                })
                ->addColumn('domain_info', function( $row ){
                    $id = $row->id;
                    $id = base64_encode($id);
                    $btn =   '<button type="button" class="btn btn-theme btn-sm btn-open-model"  onclick="infoDomain('."'$id'".')" id='."$id".' id='."$id".'>  <i class="uil uil-info-circle"></i> WHOis Info</button>'." ".
                        '<button type="button" class="btn btn-theme btn-sm btn-open-price"  onclick="priceEvaluation('."'$id'".')" id='."$id".' id='."$id".'> <i class="uil uil-file"></i > Valuations</button>';
                    return $btn;
                })
                ->addColumn('action', function( $row ){
                    $id = $row->id;
                    $id = base64_encode($id);
                    $btn =
                        '<a type="button" class="btn bg-grey" href="'.asset("admin/domain/edit/$id").'" type="button" class="btn bg-grey" data-id='.$id.'><i class="uil uil-pen"></i> Edit Domain</a>'." ".
                        '<button class="btn btn-success"   onclick="markDomain('."'$id'".')" id='."$id".'><i class="mdi mdi-cash-multiple"></i> Mark As Sold</button>'." ".
                        '<button type="button" class="btn btn-danger delete_domain" onclick="deleteDomain('."'$id'".')" id='."$id".'><i class="uil uil-trash"></i> Delete</button>';
                    return $btn;
                })
                ->rawColumns(['action','domain_info'])
                ->addColumn('domain', function( $row ){

                    return $row->domain_name;
                })
                ->addColumn('bin_price', function( $row ){

                    return '$ '.number_format($row->price);
                })
                ->addColumn('minimum_offer', function ($row) {

                    return '$ '.number_format($row->minimum_offer);
                })
                ->addColumn('monthly_visitor', function ($row) {

                    $geo = GeoLocation::whereYear('created_at', Carbon::now()->year)
                        ->whereMonth('created_at', Carbon::now()->month)->where('domain_id',$row->id)
                        ->get();
                    return count($geo);
                })
                ->addColumn('inquiries', function ($row) {

                    return "";
                })
                ->make(true);
        }
        $category = Categories::where('status','1')->get();
        return view('admin.domains.portfolio',compact('domains','category'));
    }

    public function importExcel(Request $request)
    {
       /* $UsersImport = new DomainsImport();
        Excel::import($UsersImport, $request->file);
        return redirect()->back()->with('success', "Upload Successfully");*/

        $this->validate($request, [
            'file' => 'required',
        ]);
        try {
            if ($request->file->getClientOriginalExtension() == 'xlsx' || $request->file->getClientOriginalExtension() == 'csv') {
                $size = $request->file->getSize();
                $getInKb = $size / 1000;
                $getInMb = $getInKb / 1000;

                if ($getInMb <= 3000) {
                    $StudentsImport = new DomainsImport();
                    Excel::import($StudentsImport, $request->file);
                    if (!empty($StudentsImport->value)) {

                        return redirect()->back()->withErrors($StudentsImport->value);

                    } else {
                        return redirect()->back()->withMessage('Please checks your values , unable to import');
                    }

                } else {
                    return redirect()->back()->withErrors('File should be not more than 3MB');
                }
            } else {
                return redirect()->back()->withErrors('You can upload only xlsx or csv file');

            }
        } catch (\Exception $e) {

            return redirect()->back()->with('error', 'something went wrong');
        }


    }

    public function downloadExcel()
    {
        $file=public_path("admin/import_domain_sample.xlsx");
        return Response::download($file);

    }

    public function seoSave(Request $request)
    {
        $this->validate($request, [

            'slug' => 'nullable|string|max:20',
            'logo' => 'nullable',
            'google_page_description' => 'nullable|string|max:1000',
            'google_show_page_result' => 'nullable|string|max:1000',
            'social_page_title' => 'nullable|string|max:1000',
            'social_page_description' => 'nullable|string|max:1000',
            'structured_data' => 'nullable|string|max:1000',
            'canonical' => 'nullable|string|max:1000',
            'og_site_name' => 'nullable|string|max:1000',
            'og_type' => 'nullable|string|max:1000',
            'og_url' => 'nullable|url|max:1000',

        ]);

        if(!empty($request->id))
        {
            $seo = SEOWEB::find(base64_decode($request->id));
            $seo->google_slug = $request->slug;
            $seo->google_page_title = $request->google_page_title;
            $seo->google_page_description = $request->google_page_description;
            if($request->has('google_show_page_result'))
            {
                $seo->google_show_page_result = "1";
            }
            else{
                $seo->google_show_page_result = "0";
            }

            $seo->social_page_title = $request->social_page_title;
            $seo->social_page_description = $request->social_page_description;
            $seo->structured_data = $request->structured_data;
            $seo->canonical = $request->canonical;
            $seo->og_site_name = $request->og_site_name;
            $seo->og_type = $request->og_type;
            $seo->og_url = $request->og_url;
            if(!empty($request->image))
            {
                $size = $request->image->getSize();
                $getInKb = $size / 1000;
                $getInMb = $getInKb / 1000;

                if ($getInMb <= 1000) {
                    $extension = $request->image->getClientOriginalExtension();
                    if ($extension == "jpeg" || $extension == "jpg" || $extension == "png") {
                        $large_image = public_path('admin/assets/images/seo/'.$seo->social_image);
                        File::delete($large_image);
                        $file = $request->image;
                        $imageName = Str::random(32);
                        $seo->social_image = $imageName . "." . $extension;
                        $file->move('admin/assets/images/seo', $imageName . "." . $extension);
                    } else {
                        return back()->withInput()->withErrors(['You can upload only jpg , png or jpeg']);
                    }

                }
            }
            $seo->save();
            return back()->withMessage('Upload Successfully');
        }
        else
        {
            $seo = new SEOWEB();
            $seo->google_slug = $request->slug;
            $seo->google_page_title = $request->google_page_title;
            $seo->google_page_description = $request->google_page_description;
            if($request->has('google_show_page_result'))
            {
                $seo->google_show_page_result = "1";
            }
            else{
                $seo->google_show_page_result = "0";
            }

            $seo->social_page_title = $request->social_page_title;
            $seo->social_page_description = $request->social_page_description;
            $seo->structured_data = $request->structured_data;
            $seo->canonical = $request->canonical;
            $seo->og_site_name = $request->og_site_name;
            $seo->og_type = $request->og_type;
            $seo->og_url = $request->og_url;
            if(!empty($request->image))
            {
                $size = $request->image->getSize();
                $getInKb = $size / 1000;
                $getInMb = $getInKb / 1000;

                if ($getInMb <= 1000) {
                    $extension = $request->image->getClientOriginalExtension();
                    if ($extension == "jpeg" || $extension == "jpg" || $extension == "png") {
                        $file = $request->image;
                        $imageName = Str::random(32);
                        $seo->social_image = $imageName . "." . $extension;
                        $file->move('admin/assets/images/seo', $imageName . "." . $extension);
                    } else {
                        return back()->withInput()->withErrors(['You can upload only jpg , png or jpeg']);
                    }

                }
            }
            $seo->save();
            return back()->withMessage('Upload Successfully');
        }


    }

    public function delete(Request $request)
    {
       $domain = Domains::findOrFail(base64_decode($request->ddid));
       if(isset($domain->id))
       {
          $add = Advertisement::where('domain_id',base64_decode($request->ddid))->get();
          if(count($add)>0)
          {
              Advertisement::where('domain_id',base64_decode($request->ddid))->delete();
          }
           $sub = Subscription::where('domain_id',base64_decode($request->ddid))->get();
           if(count($sub)>0)
           {
               $sub->delete();
           }
         $userSub =  UserSubscribedDomain::where('domain_id',base64_decode($request->ddid))->get();
           if(count($userSub)>0)
           {
               UserSubscribedDomain::where('domain_id',base64_decode($request->ddid))->delete();
           }
        $plan =  Plans::where('domain_id',base64_decode($request->ddid))->get();
           if(count($plan)>0)
           {
               Plans::where('domain_id',base64_decode($request->ddid))->delete();
           }
           $orders = Payments::where('domain_id',base64_decode($request->ddid))->get();
           if(count($orders)>0)
           {
              $get = Orders::find('order_id',$orders->id);
              if(isset($get->id))
              {
                  Orders::find('order_id',$orders->id)->delete();
              }
           }
           $finance = FinanceDomain::where('domain_id',base64_decode($request->ddid))->get();
           if(count($finance)>0)
           {
               FinanceDomain::where('domain_id',base64_decode($request->ddid))->delete();
           }
           $domain->delete();
       }

        return back()->withMessage('delete Successfully');
    }

public function getValuePrice(Request $request,$id )
{
    try {
        $client = new Client();
        $domain = Domains::find(base64_decode($id));
        $result = $client->request('GET', "https://api.godaddy.com/v1/appraisal/".$domain->domain_name, [
            'headers' => [
                'Content-Type' => 'application/json'
            ],

        ]);
        $getResult = json_decode($result->getBody(), true);
        return view('admin.domains.evaluation_price', compact('getResult','domain'));


    } catch (GuzzleException $e) {
        return 'something went wrong';
    }
}


}
