<?php

namespace App\Http\Controllers;

use App\CustomerAddress;
use App\Domains;
use App\DomainUsers;
use App\DummyData;
use App\Escrow;
use App\Orders;
use App\Payments;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Str;
use Session;
class EscrowController extends Controller
{
    private $escrow_key;
    private $escrow_email;
    private $escrow_url;
    private $escrow_seller_email;

    public function __construct()
    {

        $this->escrow_key = env("ESCROW_SANDBOX_API_KEY" );
        $this->escrow_email = env("ESCROW_EMAIL" );
        $this->escrow_url = env("ESCROW_URL" );
        $this->escrow_seller_email = env("ESCROW_SELLER_EMAIL" );
    }

    public function index(Request $request)
    {

        $this->validate($request, [

            'first_name' => 'required|string|max:30',
            'last_name' => 'required|string|max:30',
            'email' => 'required|email',
            'phoneCode' => 'required|string|max:30',
            'phone' => 'required|string|max:50',
            'address_1' => 'required|string|max:200',
            'address_2' => 'nullable|string|max:200',
            'city' => 'required|string|max:45',
            'state' => 'required|string|max:45',
            'zip_postal_code' => 'required|string|max:25',
            'g-recaptcha-response' => 'required',
        ]);

        $password = "";
        $email = "";
        $price = 0;
        $user_id ='';

        $user = User::where('email', $request->email)->first();
        if (empty($user)) {
            $email =$request->email;
            $password = Str::random(10);
            $user = new User();
            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->email = $request->email;
            $user->password =  Hash::make($password);
            $user->save();
            $user_id = $user->id;
        } else {
            $user_id = $user->id;
        }


        Session::put('user_id', $user_id);
        Session::put('city', $request->city);
        Session::put('state', $request->state);
        Session::put('country', $request->country);
        Session::put('zip_post', $request->zip_postal_code);
        Session::put('phone', $request->phoneCode . $request->phone);
        Session::put('address_1',$request->address_1);
        Session::put('address_2', $request->address_2);
        Session::put('total_price', $price);
        Session::put('first_name', $request->first_name);
        Session::put('last_name', $request->last_name);
        Session::put('password', $password);
        Session::put('email', $request->email);

        $domains = $domains = Domains::whereIn('id', Session::get('id'))->get();
        foreach ($domains as $domain) {
            if ($domain->sold != "0") {
                return redirect()->back()->withErrors($domain->domain_name . " already sold");
            }
          $itemArr =  array(
                'description' => 'Purchasing Domain '.$domain->domain_name,
                'schedule' => array(
                    array(
                        'payer_customer' => $request->email,
                        'amount' => $domain->price,
                        'beneficiary_customer' => $this->escrow_seller_email,
                    ),
                ),
                'title' => $domain->domain_name,
                'inspection_period' => '86400',
                'type' => 'domain_name',
                'quantity' => '1',
                'extra_attributes' => array(
                    "concierge" => false,
                    "with_content" => false
                ),
            );
        }


        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL => $this->escrow_url.'/integration/pay/2018-03-31',
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_USERPWD => $this->escrow_email.':'.$this->escrow_key,
            CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json'
            ),
            CURLOPT_POSTFIELDS => json_encode(
                array(
                    'currency' => 'usd',

                    'return_url' => $request->root()."/escrow/after/payment",
                    'redirect_type' => "automatic",
                    'payment_method' => 'credit_card',
                    'items' => array(
                      $itemArr
                    ),
                    'description' => 'The sale of domain',
                    'parties' => array(
                        array(
                            'agreed' => 'true',
                            'customer' => $request->email,
                            'first_name' => $request->first_name,
                            'initiator' => 'true',
                            'last_name' => $request->last_name,
                            'phone_number' => $request->phone,
                            'role' => 'buyer',
                            'lock_email', 'true',
                        ),
                        array(
                            'agreed' => 'true',
                            'customer' => $this->escrow_seller_email,
                            'role' => 'seller',
                        ),
                    ),
                )
            )

        ));

        $output = curl_exec($curl);
        $getUrl = json_decode($output,true);
        curl_close($curl);
        if(isset($getUrl['landing_page']))
        {
            Session::put('transaction_id', $getUrl['transaction_id']);
          return  Redirect::to($getUrl['landing_page']);
        }


    /*    Session::forget('id');
        Session::forget('transaction_id');
        Session::forget('user_id');
        Session::forget('city');
        Session::forget('state');
        Session::forget('country');
        Session::forget('zip_post');
        Session::forget('phone');
        Session::forget('address_1');
        Session::forget('address_2');
        Session::forget('total_price');
        Session::forget('first_name');
        Session::forget('last_name');
        Session::forget('password');
        Session::forget('email');*/
        return redirect()->back()->withErrors("Something went wrong");

    }

    public function afterPayment(Request $request)
    {

        $email= Session::get('email');
        $order = new Orders();
        $order->user_id = Session::get('user_id');
        $order->city = Session::get('city');
        $order->state = Session::get('state');
        $order->country = Session::get('country');
        $order->zip_post = Session::get('zip_post');
        $order->payment_method = 'escrow';
        $order->status = 'pending';
        $order->phone = Session::get('phone');
        $order->address_1 = Session::get('address_1');
        $order->address_2 = Session::get('address_2');
        $order->total_price = Session::get('total_price');
        $order->save();

        $escrow = new Escrow();
        $escrow->order_id = $order->id;
        $escrow->transaction_id = Session::get('transaction_id');
        $escrow->save();

        $domains = $domains = Domains::whereIn('id', Session::get('id'))->get();
        foreach ($domains as $key => $domain) {

            $payment1 = new Payments();
            $payment1->price = $domain->price;
            $payment1->order_id = $order->id;
            $payment1->domain_id = $domain->id;
            $payment1->save();
            $domain->sold = "1";
            $domain->save();


            $password = Str::random(10);
            $domain_user = new DomainUsers();
            $domain_user->domain_id = $domain->id;
            $domain_user->user_id = Session::get('user_id');
            $domain_user->password = Hash::make($password);
            $domain_user->status = 'active';
            $domain_user->save();


            $getStripeCustomerId = new CustomerAddress();
            $getStripeCustomerId->domain_id = $domain->id;
            $getStripeCustomerId->active = '1';
            $getStripeCustomerId->first_name = Session::get('first_name');
            $getStripeCustomerId->last_name = Session::get('last_name');
            $getStripeCustomerId->user_id = Session::get('user_id');
            $getStripeCustomerId->city = Session::get('city');
            $getStripeCustomerId->state = Session::get('state');
            $getStripeCustomerId->country = Session::get('country');
            $getStripeCustomerId->zip_post = Session::get('zip_post');
            $getStripeCustomerId->phone = Session::get('phone');
            $getStripeCustomerId->address_1 = Session::get('address_1');
            $getStripeCustomerId->address_2 = Session::get('address_2');
            $getStripeCustomerId->save();

           /* $domain_name = $domain->domain_name;
            Mail::send('emails.registration', compact('password', 'domain_name'), function ($message) use ($email, $domain_name) {
                $message->from('sales@zdomainname.com', "zDomainName");
                $message->subject("zDomainName : " . $domain_name . "Purchased ");
                $message->to($email);
            });*/

            Mail::send('emails.registration', compact('password','domain_name'), function ($message) use ($email,$domain_name) {
                $message->from('sales@zdomainname.com', "zDomainName");
                $message->subject("zDomainName : ".$domain_name ."Purchased ");
                $message->to($email);
            });

            Mail::send('emails.purchase', compact('order'), function ($message) use ($email,$domain_name) {
                $message->from('sales@zdomainname.com', "zDomainName");
                $message->subject("zDomainName : ".$domain_name ."Purchased ");
                $message->to($email);
            });

        }
        Session::forget('id');
        Session::forget('transaction_id');
        Session::forget('user_id');
        Session::forget('city');
        Session::forget('state');
        Session::forget('country');
        Session::forget('zip_post');
        Session::forget('phone');
        Session::forget('address_1');
        Session::forget('address_2');
        Session::forget('total_price');
        Session::forget('first_name');
        Session::forget('last_name');
        Session::forget('password');
        Session::forget('email');
            return Redirect::to($request->root() . "/user/thankyou");

    }
    public function getTransaction()
    {
        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL => $this->escrow_url.'/2017-09-01/transaction/3771090',
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_USERPWD => $this->escrow_email.':'.$this->escrow_key,
            CURLOPT_HTTPHEADER => array(
                'Content-Type: application/json'
            ),
        ));

        $output = curl_exec($curl);
        $getData = json_decode($output,true);
        dd($getData);
        curl_close($curl);
    }

    public function webHook(Request $request)
    {
        $dummy = new DummyData();
        $dummy->data = 'sssss';
        $dummy->save();
        return $dummy;
    }
}
