<?php

namespace App\Http\Controllers;

use App\Domains;
use App\DomainSettings;
use App\GeoLocation;
use App\MakeOffer;
use App\MakeOfferGeoLocation;
use Carbon\Carbon;
use GuzzleHttp\Client;
use Illuminate\Http\Request;

class MakeOfferController extends Controller
{
    public function makeOffer(Request $request)
    {
        $this->validate($request, [

            'name' => 'required|string|max:30',
            'note' => 'required|string|max:200',
            'email' => 'required|email',
            'phone' => 'required|string|max:50',
            'have_company_check' => 'required|string|max:200',
            'g-recaptcha-response' => 'required',
        ]);


        try {

            $domainSetting = DomainSettings::first();
            $domain = Domains::find(base64_decode($request->id));

            $offer = new MakeOffer();
            $offer->company_name = $request->note;
            $offer->domain_id = base64_decode($request->id);
            $offer->name = $request->name;
            $offer->is_read = "0";
            $offer->email = $request->email;
            if ($request->has('terms_policy_check')) {
                $offer->terms_policy = "varified";
            } else {
                $offer->terms_policy = "not verified";
            }
            $offer->phone = $request->phone;
            $offer->price = $request->price;


            $client = new Client();
            $getData = $client->request('GET', "https://ip-geolocation.whoisxmlapi.com/api/v1?apiKey=at_h0xMLQJOy9YEWrLGb2HZlHr4fumlL&ipAddress=".$_SERVER['REMOTE_ADDR'], [
            ]);
            $getResult = json_decode($getData->getBody(), true);

            $geoLocation = new MakeOfferGeoLocation();
            $geoLocation->domain_id = base64_decode($request->id);
            $geoLocation->offer_id = $offer->id;
            $geoLocation->ip = isset($getResult['ip']) ? $getResult['ip'] : '';
            $geoLocation->country = isset($getResult['location']['country']) ? $getResult['location']['country'] : '';
            $geoLocation->region = isset($getResult['location']['region']) ? $getResult['location']['region'] : '';
            $geoLocation->city = isset($getResult['location']['city']) ? $getResult['location']['city'] : '';
            $geoLocation->lat = isset($getResult['location']['lat']) ? $getResult['location']['lat'] : '';
            $geoLocation->lng = isset($getResult['location']['lng']) ? $getResult['location']['lng'] : '';
            $geoLocation->postal_code = isset($getResult['location']['postal_code']) ? $getResult['location']['postal_code'] : '';
            $geoLocation->time_zone = isset($getResult['location']['timezone']) ? $getResult['location']['timezone'] : '';
            $geoLocation->isp = isset($getResult['isp']) ? $getResult['isp'] : '';
            $geoLocation->connection_type = isset($getResult['connectionType']) ? $getResult['connectionType'] : '';
            $geoLocation->geoname_id = isset($getResult['location']['geonameId']) ? $getResult['location']['geonameId'] : '';
            $geoLocation->asn = isset($getResult['as']['asn']) ? $getResult['as']['asn'] : '';
            $geoLocation->name = isset($getResult['as']['name']) ? $getResult['as']['name'] : '';
            $geoLocation->route = isset($getResult['as']['route']) ? $getResult['as']['route'] : '';
            $geoLocation->type = isset($getResult['as']['type']) ? $getResult['as']['type'] : '';

            if (!empty($domain->minimum_offer)) {
                if ($domain->minimum_offer <= $request->price) {
                    $offer->save();
                    $geoLocation->offer_id = $offer->id;
                    $geoLocation->save();

                } else {
                    return redirect()->back()->WithErrors("Your offer must be equal or higher than $" . number_format($domain->minimum_offer));
                }

            } else if (isset($domainSetting->id)) {
                if ($domainSetting->price <= $request->price) {
                    $offer->save();
                    $geoLocation->offer_id = $offer->id;
                    $geoLocation->save();

                } else {
                    return redirect()->back()->WithErrors("Your offer must be equal or higher than $" . number_format($domainSetting->price));
                }
            } else {
                $offer->save();
                $geoLocation->offer_id = $offer->id;
                $geoLocation->save();
            }


            return redirect()->back()->withMessage("Make Offer Successfully");


        } catch (GuzzleException $e) {

            MakeOffer::find($offer->id)->delete();
            return redirect()->back()->withErrors("Something went wrong");
        }
    }
}
