<?php

namespace App\Http\Controllers;

use App\CustomerAddress;
use App\Domains;
use App\DomainUsers;
use App\Orders;
use App\Payments;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Str;
use PayPal\Api\Amount;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Rest\ApiContext;
use Session;
class PayPallController extends Controller
{
    public function __construct()
    {
        /** PayPal api context **/
        $paypal_conf = \Config::get('paypal');
        $this->_api_context = new ApiContext(new OAuthTokenCredential(
                $paypal_conf['client_id'],
                $paypal_conf['secret'])
        );
        $this->_api_context->setConfig($paypal_conf['settings']);
    }

    public function payWithpaypal(Request $request)
    {

        $this->validate($request, [

            'first_name' => 'required|string|max:30',
            'last_name' => 'required|string|max:30',
            'email' => 'required|email',
            'phoneCode' => 'required|string|max:30',
            'phone' => 'required|string|max:50',
            'address_1' => 'required|string|max:200',
            'address_2' => 'nullable|string|max:200',
            'city' => 'required|string|max:45',
            'state' => 'required|string|max:45',
            'zip_postal_code' => 'required|string|max:25',
            'g-recaptcha-response' => 'required',
        ]);
        $password = "";
        $email = "";
        $price = 0;
        $user_id ='';

        $user = User::where('email', $request->email)->first();
        if (empty($user)) {
            $email =$request->email;
            $password = Str::random(10);
            $user = new User();
            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            $user->email = $request->email;
            $user->password =  Hash::make($password);
            $user->save();
            $user_id = $user->id;
        } else {
            $user_id = $user->id;
        }

        $domains = $domains = Domains::whereIn('id', Session::get('id'))->get();
        foreach ($domains as $domain) {
            if ($domain->sold != "0") {
                return redirect()->back()->withErrors($domain->domain_name . " already sold");
            }
            $price = $price + $domain->price;
        }

        $payer = new Payer();
        $payer->setPaymentMethod('paypal');

        $amount = new Amount();
        $amount->setCurrency('USD')
            ->setTotal($price);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setDescription('Paid for domain purchase purpose');
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl('https://home.zdomainname.com/paypal/done') /** Specify return URL **/
        ->setCancelUrl('https://home.zdomainname.com/paypal/cancel');
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {


            Session::put('user_id', $user_id);
            Session::put('city', $request->city);
            Session::put('state', $request->state);
            Session::put('country', $request->country);
            Session::put('zip_post', $request->zip_postal_code);
            Session::put('phone', $request->phoneCode . $request->phone);
            Session::put('address_1',$request->address_1);
            Session::put('address_2', $request->address_2);
            Session::put('total_price', $price);
            Session::put('first_name', $request->first_name);
            Session::put('last_name', $request->last_name);
            Session::put('password', $password);
            Session::put('email', $request->email);


            $payment->create($this->_api_context);



        } catch (\PayPal\Exception\PPConnectionException $ex) {
            if (\Config::get('app.debug')) {
               // \Session::put('error', 'Connection timeout');
                return redirect()->back()->withErrors("Connection timeout");
              //  return Redirect::route('paywithpaypal');
            } else {
                //\Session::put('error', 'Some error occur, sorry for inconvenient');
               // return Redirect::route('paywithpaypal');
                return redirect()->back()->withErrors("Some error occur, sorry for inconvenient");
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return Redirect::away($redirect_url);
        }
      //  \Session::put('error', 'Unknown error occurred');
     //   return Redirect::route('paywithpaypal');
        return redirect()->back()->withErrors("Unknown error occurred");
    }

    public function payWithpaypalSuccess (Request $request)
    {



        $email= Session::get('email');

        $order = new Orders();
        $order->user_id =  Session::get('user_id');
        $order->city =   Session::get('city');
        $order->state =   Session::get('state');
        $order->country = Session::get('country');
        $order->zip_post =  Session::get('zip_post');
        $order->payment_method =  'paypal';
        $order->status =  'paid';
        $order->phone =  Session::get('phone');
        $order->address_1 =  Session::get('address_1');
        $order->address_2 =  Session::get('address_2');
        $order->total_price =  Session::get('total_price');
        $order->save();

        $domains = $domains = Domains::whereIn('id', Session::get('id'))->get();
        foreach ($domains as $key => $domain) {

            $payment1 = new Payments();
            $payment1->price = $domain->price;
            $payment1->order_id = $order->id;
            $payment1->domain_id = $domain->id;
            $payment1->save();
            $domain->sold = "1";
            $domain->save();


            $password = Str::random(10);
            $domain_user = new DomainUsers();
            $domain_user->domain_id = $domain->id;
            $domain_user->user_id = Session::get('user_id');
            $domain_user->password = Hash::make($password);
            $domain_user->status = 'active';
            $domain_user->save();



            $getStripeCustomerId = new CustomerAddress();
            $getStripeCustomerId->domain_id =  $domain->id;
            $getStripeCustomerId->active =  '1';
            $getStripeCustomerId->first_name = Session::get('first_name');
            $getStripeCustomerId->last_name =  Session::get('last_name');
            $getStripeCustomerId->user_id =  Session::get('user_id');
            $getStripeCustomerId->city =  Session::get('city');
            $getStripeCustomerId->state =  Session::get('state');
            $getStripeCustomerId->country =  Session::get('country');
            $getStripeCustomerId->zip_post =  Session::get('zip_post');
            $getStripeCustomerId->phone =  Session::get('phone');
            $getStripeCustomerId->address_1 =  Session::get('address_1');
            $getStripeCustomerId->address_2 =  Session::get('address_2');
            $getStripeCustomerId->save();

            $domain_name = $domain->domain_name;
            Mail::send('emails.registration', compact('password','domain_name'), function ($message) use ($email,$domain_name) {
                $message->from('sales@zdomainname.com', "zDomainName");
                $message->subject("zDomainName : ".$domain_name ."Purchased ");
                $message->to($email);
            });

            Mail::send('emails.purchase', compact('order'), function ($message) use ($email,$domain_name) {
                $message->from('sales@zdomainname.com', "zDomainName");
                $message->subject("zDomainName : ".$domain_name ."Purchased ");
                $message->to($email);
            });

        }

        /*if(!empty($password))
        {

            Mail::send('emails.registration', compact('password'), function ($message) use ($email) {
                $message->from('no-reply@temperaturekiosk.com', "New Registration");
                $message->subject("New Registration");
                $message->to($email);
            });
        }*/




        Session::forget('id');
        Session::forget('user_id');
        Session::forget('city');
        Session::forget('state');
        Session::forget('country');
        Session::forget('zip_post');
        Session::forget('phone');
        Session::forget('address_1');
        Session::forget('address_2');
        Session::forget('total_price');
        Session::forget('first_name');
        Session::forget('last_name');
        Session::forget('password');
        Session::forget('email');
        return Redirect::to($request->root() . "/user/thankyou");
    }
    public function payWithpaypalCancel()
    {


        Session::forget('id');
        Session::forget('user_id');
        Session::forget('city');
        Session::forget('state');
        Session::forget('country');
        Session::forget('zip_post');
        Session::forget('phone');
        Session::forget('address_1');
        Session::forget('address_2');
        Session::forget('total_price');
        Session::forget('first_name');
        Session::forget('last_name');
        Session::forget('password');
        Session::forget('email');

        return redirect()->back()->withErrors("payment cancelled");

    }
}
