<?php

namespace App\Http\Controllers;

use App\Countries;
use App\CustomerAddress;
use App\Domains;
use App\DomainUsers;
use App\Orders;
use App\Payments;
use App\Plans;
use App\Subscription;
use App\SubscriptionPayments;
use App\User;
use App\UserSubscribedDomain;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Stripe;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Crypt;

class SubscriptionController extends Controller
{
    public function index (Request $request)
    {
        $this->validate($request, [

            'month' => 'required',

        ]);
        if(app('router')->getRoutes()->match(app('request')->create(URL::previous()))->getName() == 'priceplane' ||
            app('router')->getRoutes()->match(app('request')->create(URL::previous()))->getName() == 'subscriptionCheckout') {
            $plan = Plans::find(base64_decode($request->id));
            $price = $plan->price / base64_decode($request->month);
            $domain = Domains::find($plan->domain_id);
            $total = $price + ($plan->month_3_interest / $price * 100) + ($plan->month_3_apr / $price * 100);
            $total = number_format($total, 2, '.', ' ');
            $month = $request->month;
            $countries = Countries::all();
            return view('checkout_subscription', compact('month', 'total', 'domain', 'countries'));
        }
    }

    public function payment(Request $request)
    {


        $this->validate($request, [

            'card' => 'required|regex:/^[0-9\s]*$/',
            'cvc' => 'required|numeric',
            'month' => 'required|numeric',
            'year' => 'required|numeric',
            'first_name' => 'required|string|max:30',
            'last_name' => 'required|string|max:30',
            'email' => 'required|email',
            'phoneCode' => 'required|string|max:30',
            'phone' => 'required|string|max:50',
            'card_name' => 'required|string|max:30',
            'address_1' => 'required|string|max:1000',
            'address_2' => 'nullable|string|max:1000',
            'country' => 'nullable|string|max:1000',
            'city' => 'required|string|max:45',
            'state' => 'required|string|max:45',
            'zip_postal_code' => 'required|string|max:25',

        ]);
        try {
            $password = "";
            $email = "";
            Stripe\Stripe::setApiKey(env("STRIPE_SECRET" ));

            $user = User::where('email', $request->email)->first();
            if (empty($user)) {
                $email =$request->email;
                $password = Str::random(10);
                $user = new User();
                $user->first_name = $request->first_name;
                $user->last_name = $request->last_name;
                $user->email = $request->email;
                $user->password =  Hash::make($password);
                $user->save();
                $user_id = $user->id;
            } else {
                $user_id = $user->id;
            }


            $domain = Domains::find(base64_decode($request->id));

                if ($domain->sold == "1" || $domain->sold == "2") {
                    return redirect()->back()->withErrors($domain->domain_name . " already sold");
                }
            $plan = Plans::where('domain_id',base64_decode($request->id))->first();
            $price = $plan->price/base64_decode($request->month_plan);
            $total = $price + ($plan->month_3_interest /$price * 100) + ($plan->month_3_apr/$price*100);

            $total = number_format($total, 2, '.', '');
            $getUser = User::find($user_id);

                $customer = \Stripe\Customer::create([
                    'email' => $request->email,
                    'description' => "This customer " .$request->first_name . " " . $request->last_name." is created for zDomain subscription purpose",
                    'source' => $request->stripeToken,
                ]);
                $encrypted = Crypt::encryptString($customer->id);

            $priceObj = \Stripe\Price::create([
                'unit_amount' => 100 * $total,
                'currency' => 'usd',
                "livemode" => false,
                'recurring' => ['interval' => 'month'],
                'product_data' => ['name' => 'Regular Subscription for the period of '.$plan->selected_month." months. This is created for domain ".$domain->domain_name]
            ]);

            $expireSubscriptionDate = Carbon::now()->addMonths($plan->selected_month);
            $subscriptionObj = \Stripe\Subscription::create([
                'customer' => $customer->id,
                'canceled_at' => strtotime($expireSubscriptionDate->toDateString()),
                'items' => [['price' => $priceObj->id]]
            ]);



          /*  $statusPaid = Stripe\Charge::create([
                "amount" => 100 * $total,
                "currency" => "usd",
                "description" => $request->first_name . " " . $request->last_name . " with Email " . $request->email . " purchased domains ",
                "customer" =>   $customer->id
            ]);*/

            $subs = new Subscription();
            if ($subscriptionObj->status == 'active') {
                $domain->sold = "2";
                $domain->save();
                $newDateTime = Carbon::now()->addMonths(base64_decode($request->month_plan));
                $subs->user_id = $user_id;
                $subs->domain_id = $domain->id;
                $subs->payment_status = 'paid';
                $subs->subscription_status = 'active';
                $subs->next_date = $newDateTime->toDateString();
                $subs->stripe_customer_id =  Crypt::encryptString($customer->id);
                $subs->stripe_price_id =  Crypt::encryptString($priceObj->id);
                $subs->stripe_subscription_id =  Crypt::encryptString($subscriptionObj->id);
                $subs->save();

                $getStripeCustomerId = new CustomerAddress();
                $getStripeCustomerId->domain_id =  $domain->id;
                $getStripeCustomerId->active =  '1';
                $getStripeCustomerId->first_name =  $request->first_name;
                $getStripeCustomerId->last_name =  $request->last_name;
                $getStripeCustomerId->stripe_customer_id = $encrypted;
                $getStripeCustomerId->user_id = $user_id;
                $getStripeCustomerId->city = $request->city;
                $getStripeCustomerId->state = $request->state;
                $getStripeCustomerId->country = $request->country;
                $getStripeCustomerId->zip_post = $request->zip_postal_code;
                $getStripeCustomerId->phone = $request->phoneCode . $request->phone;
                $getStripeCustomerId->address_1 = $request->address_1;
                $getStripeCustomerId->address_2 = $request->address_2;
                $getStripeCustomerId->save();

                $order = new SubscriptionPayments();
                $order->user_id = $user_id;
                $order->domain_id = $domain->id;
                $order->city = $request->city;
                $order->state = $request->state;
                $order->country = $request->country;
                $order->zip_post = $request->zip_postal_code;
                $order->phone = $request->phoneCode . $request->phone;
                $order->address_1 = $request->address_1;
                $order->address_2 = $request->address_2;
                $order->card_name = $request->card_name;
                $order->total_price_paid = $total;
                $order->apr =  $plan->month_3_apr;
                $order->month =  base64_decode($request->month_plan);
                $order->interest = $plan->month_3_apr;
                $order->price = number_format($plan->price/base64_decode($request->month_plan), 2, '.', ' ');
                $order->payment_method = 'stripe';
            /*    $order->stripe_payment_method = $statusPaid->payment_method;
                $order->stripe_payment_id = $statusPaid->id;*/
                $order->subscription_id = $subs->id;
                $order->save();

                $password = Str::random(10);
                $domain_user = new DomainUsers();
                $domain_user->domain_id = $domain->id;
                $domain_user->user_id = $user_id;
                $domain_user->password = Hash::make($password);
                $domain_user->status = 'active';
                $domain_user->save();

                $userSubscribedDomain = new UserSubscribedDomain();
                $userSubscribedDomain->user_id = $user_id;
                $userSubscribedDomain->domain_id = $domain->id;
                $userSubscribedDomain->domain_name = $domain->domain_name;
                $userSubscribedDomain->total_paid = $total;
                $userSubscribedDomain->remaining_payable = $plan->price - round($total);
                $userSubscribedDomain->count = "1";
                $userSubscribedDomain->next_date = $newDateTime->toDateString();
                $userSubscribedDomain->month = base64_decode($request->month_plan);
                $userSubscribedDomain->status = "active";
                $userSubscribedDomain->save();

                $domain_name = $domain->domain_name;
                $email = $request->email;

                Mail::send('emails.registration', compact('password','domain_name'), function ($message) use ($email,$domain_name) {
                    $message->from('sales@zdomainname.com', "zDomainName");
                    $message->subject("zDomainName : ".$domain_name ."Purchased ");
                    $message->to($email);
                });

                Mail::send('emails.purchase', compact('order'), function ($message) use ($email,$domain_name) {
                    $message->from('sales@zdomainname.com', "zDomainName");
                    $message->subject("zDomainName : ".$domain_name ."Purchased ");
                    $message->to($email);
                });

                Mail::send('emails.thank_you_subs', compact('order'), function ($message) use ($email,$domain_name) {
                    $message->from('sales@zdomainname.com', "zDomainName");
                    $message->subject("zDomainName : ".$domain_name ."Purchased ");
                    $message->to($email);
                });
              //  return redirect()->back()->withMessage("Paid Successfully");
                return Redirect::to($request->root() . "/user/thankyou");

            }
            else
            {
                $stripe = new \Stripe\StripeClient(
                    env("STRIPE_SECRET" )
                );
                $stripe->customers->delete(
                    $customer->id
                );

                $stripe->subscriptions->cancel(
                   $subscriptionObj->id

                );
                return redirect()->back()->withErrors("Subscription Failed ,Please try again");
            }

        } catch (\Exception $e) {

            return redirect()->back()->withErrors("something went wrong");
        }

    }


    public function webHooks(Request $request)
    {
        $data = $request->data;
        $obj = $data['object'];
        $price = $obj['amount'];
        $customer_id = $obj['customer'];

        if($request->type == "charge.succeeded")
        {

            $checkSubs = Subscription::where('stripe_customer_id',Crypt::decryptString($customer_id))->where('status','!=','cancelled')->first();
            if(isset($checkSubs->id))
            {
                $savePayment = new SubscriptionPayments();
                $savePayment->price = $price/100;
                $savePayment->user_id = $checkSubs->user_id;
                $savePayment->domain_id =  $checkSubs->domain_id;
                $savePayment->city =  $checkSubs->city;
                $savePayment->state =  $checkSubs->state;
                $savePayment->country = $checkSubs->country;
                $savePayment->zip_post = $checkSubs->zip_post;
                $savePayment->phone = $checkSubs->phone;
                $savePayment->address_1 =  $checkSubs->address_1;
                $savePayment->address_2 = $checkSubs->address_2;
                $savePayment->card_name =  $checkSubs->card_name;
                $savePayment->total_price_paid =  $checkSubs->total_price_paid;
                $savePayment->apr =   $checkSubs->apr;
                $savePayment->month =   $checkSubs->month;
                $savePayment->interest = $checkSubs->interest;
                $savePayment->payment_method = 'stripe';
                $savePayment->subscription_id =  $checkSubs->subscription_id;
                $savePayment->save();

                $userSubsDomain = UserSubscribedDomain::where('domain_id' ,$checkSubs->domain_id)->first();

                if(isset($userSubsDomain->id))
                {
                    $userSubsDomain->total_paid = $userSubsDomain->total_paid + ($price/100);
                    $userSubsDomain->remaing_payable =  $userSubsDomain->remaing_payable - ($price/100);
                    $userSubsDomain->next_date =   $newDateTime = Carbon::now()->addMonths($userSubsDomain->next_date);
                    $userSubsDomain->count = $userSubsDomain->count + 1;
                    $userSubsDomain->save();
                }

            }
        }
        if($request->type == "charge.failed")
        {
            $checkSubs = Subscription::where('stripe_customer_id',$customer_id)->where('status','!=','cancelled')->first();
            if(isset($checkSubs->id)) {
                $checkSubs->status = 'failed';
                $checkSubs->payment_status = 'pending';
                $checkSubs->save();

                $domain = Domains::find($checkSubs->domain_id);
                $user = User::find($domain->user_id);
                Mail::send('emails.failed_subs', compact('domain'), function ($message) use ($user,$domain) {
                    $message->from('sales@zdomainname.com', "zDomainName");
                    $message->subject("zDomainName : ".$domain->domain_name ."Subscription Failed");
                    $message->to($user->email);
                });
            }
        }

        if($request->type == "charge.expired")
        {
            $checkSubs = Subscription::where('stripe_customer_id',$customer_id)->where('status','!=','cancelled')->first();
            if(isset($checkSubs->id)) {
                $checkSubs->status = 'failed';
                $checkSubs->payment_status = 'pending';
                $checkSubs->save();

                $domain = Domains::find($checkSubs->domain_id);
                $user = User::find($domain->user_id);
                Mail::send('emails.failed_subs', compact('domain'), function ($message) use ($user,$domain) {
                    $message->from('sales@zdomainname.com', "zDomainName");
                    $message->subject("zDomainName : ".$domain->domain_name ."Subscription Failed");
                    $message->to($user->email);
                });
            }
        }

    }
}
